@@ -1,3 +1,4 @@
+from enum import auto
 import time
 import requests
 import base64, hashlib, hmac
@@ -859,6 +860,14 @@ class Client(object):
 
     def get_server_time(self, datetime_output:bool=False) -> int:
         """Return server time in UTC time to millisecond granularity
+
+        Notes
+        -----
+            This function will return the KuCoin official server time in UTC as unix epoch.
+            Returned time is an integer value representing time to millisecond precision. 
+            This function should be used to sync client and server time as orders submitted 
+            with a timestamp over 5 seconds old will be rejected by the server. In some cases,
+            client time can lag server time resulting in the server rejected commands as stale.
         
         Parameters
         ----------
@@ -901,18 +910,18 @@ class Client(object):
         price : float 
             Trades must be executed at this price or better
         size : float
-            (Optional) Size in base currency to buy or sell 
-            Size indicates the amount of base currency to buy or sell
-            Size must be above baseMinSize and below baseMaxSize
-            Size must be specified in baseIncrement symbol units
-            Size must be a positive float value
-            Note: User is required to either specify size or funds. 
+            (Optional) Size in base currency to buy or sell.
+            | Size indicates the amount of base currency to buy or sell
+            | Size must be above baseMinSize and below baseMaxSize
+            | Size must be specified in baseIncrement symbol units
+            | Size must be a positive float value
+            | Note: User is required to either specify size or funds. 
         funds : float
-            (Optional) Amount of funds in quote currency to buy or sell
-            Note: User is required to either specify size or funds.
-            Funds indicates the amount of price [quote] currency to buy or sell.
-            Funds must be above quoteMinSize and below quoteMaxSize
-            Size must be specified in quoteIncrement symbol units
+            (Optional) Amount of funds in quote currency to buy or sell.
+            | Note: User is required to either specify size or funds.
+            | Funds indicates the amount of price [quote] currency to buy or sell.
+            | Funds must be above quoteMinSize and below quoteMaxSize
+            | Size must be specified in quoteIncrement symbol units
         client_oid : int
             (Optional) Unique order ID for identification of orders. 
             Defaults to integer nonce based on unix epoch if unspecified.
@@ -987,18 +996,18 @@ class Client(object):
             Side on which to execute trade.
             Options: buy or sell
         size : float
-            (Optional) Size in base currency to buy or sell 
-            Size indicates the amount of base currency to buy or sell
-            Size must be above baseMinSize and below baseMaxSize
-            Size must be specified in baseIncrement symbol units
-            Size must be a positive float value
-            Note: User is required to either specify size or funds. 
+            (Optional) Size in base currency to buy or sell.
+            | Size indicates the amount of base currency to buy or sell
+            | Size must be above baseMinSize and below baseMaxSize
+            | Size must be specified in baseIncrement symbol units
+            | Size must be a positive float value
+            | Note: User is required to either specify size or funds. 
         funds : float
-            (Optional) Amount of funds in quote currency to buy or sell
-            Note: User is required to either specify size or funds.
-            Funds indicates the amount of price [quote] currency to buy or sell.
-            Funds must be above quoteMinSize and below quoteMaxSize
-            Size must be specified in quoteIncrement symbol units
+            (Optional) Amount of funds in quote currency to buy or sell.
+            | Note: User is required to either specify size or funds.
+            | Funds indicates the amount of price [quote] currency to buy or sell.
+            | Funds must be above quoteMinSize and below quoteMaxSize
+            | Size must be specified in quoteIncrement symbol units
         client_oid : int
             (Optional) Unique order ID for identification of orders. 
             Defaults to integer nonce based on unix epoch if unspecified.
@@ -1040,6 +1049,17 @@ class Client(object):
     ):
         """API command for placing market trades on margin. 
 
+        Notes
+        -----
+            Due to a glitch in KuCoin's API handling of autoborrowed funds, the server
+            will sometimes return the following:
+                `{'code': '300000', 'msg': 'Order funds invalid.'}`
+            This issue arises with certain combinations of side, size/funds and only 
+            while autoborrow is true. I am currently working on a way around this, but 
+            as the glitch appears to be server side there may be no elegant solution.
+            Users are recommended to either use the `margin_limit_order` function which works
+            as intended or to manually borrow funds and set autoborrow to False.
+
         Parameters
         ----------
         symbol : str
@@ -1048,18 +1068,18 @@ class Client(object):
             Side on which to execute trade.
             Options: buy or sell
         size : float
-            (Optional) Size in base currency to buy or sell 
-            Size indicates the amount of base currency to buy or sell
-            Size must be above baseMinSize and below baseMaxSize
-            Size must be specified in baseIncrement symbol units
-            Size must be a positive float value
-            Note: User is required to either specify size or funds. 
+            (Optional) Size in base currency to buy or sell.
+            | Size indicates the amount of base currency to buy or sell
+            | Size must be above baseMinSize and below baseMaxSize
+            | Size must be specified in baseIncrement symbol units
+            | Size must be a positive float value
+            | Note: User is required to either specify size or funds. 
         funds : float
-            (Optional) Amount of funds in quote currency to buy or sell
-            Note: User is required to either specify size or funds.
-            Funds indicates the amount of price [quote] currency to buy or sell.
-            Funds must be above quoteMinSize and below quoteMaxSize
-            Size must be specified in quoteIncrement symbol units
+            (Optional) Amount of funds in quote currency to buy or sell.
+            | Note: User is required to either specify size or funds.
+            | Funds indicates the amount of price [quote] currency to buy or sell.
+            | Funds must be above quoteMinSize and below quoteMaxSize
+            | Size must be specified in quoteIncrement symbol units
         client_oid : int
             (Optional) Unique order ID for identification of orders. 
             Defaults to integer nonce based on unix epoch if unspecified.
@@ -1128,18 +1148,18 @@ class Client(object):
         price : float 
             Trades must be executed at this price or better
         size : float
-            (Optional) Size in base currency to buy or sell 
-            Size indicates the amount of base currency to buy or sell
-            Size must be above baseMinSize and below baseMaxSize
-            Size must be specified in baseIncrement symbol units
-            Size must be a positive float value
-            Note: User is required to either specify size or funds. 
+            (Optional) Size in base currency to buy or sell.
+            | Size indicates the amount of base currency to buy or sell
+            | Size must be above baseMinSize and below baseMaxSize
+            | Size must be specified in baseIncrement symbol units
+            | Size must be a positive float value
+            | Note: User is required to either specify size or funds. 
         funds : float
-            (Optional) Amount of funds in quote currency to buy or sell
-            Note: User is required to either specify size or funds.
-            Funds indicates the amount of price [quote] currency to buy or sell.
-            Funds must be above quoteMinSize and below quoteMaxSize
-            Size must be specified in quoteIncrement symbol units
+            (Optional) Amount of funds in quote currency to buy or sell.
+            | Note: User is required to either specify size or funds.
+            | Funds indicates the amount of price [quote] currency to buy or sell.
+            | Funds must be above quoteMinSize and below quoteMaxSize
+            | Size must be specified in quoteIncrement symbol units
         client_oid : int
             (Optional) Unique order ID for identification of orders. 
             Defaults to integer nonce based on unix epoch if unspecified.
